##############################################
#
# multimedia_cell
# Module | Multimedia Cell Module.
#
# Daniel Bakas Amuchastegui
# February 20, 2020
# 
# Copyright © Semantyk 2020. All rights reserved.
#############################################

from semantyk.data_visualization_models.cell.cell import Cell

class MultimediaCell(Cell):
    pass